## **Overview**

Hi Everyone!

This repository contains a statistical software package written in Cython. All matrix algebra and statistical formulas are coded by hand, leveraging Cython's static variable declaration and memory views for more efficient operations.

My Auto Linear Transformation (ALTOLS) algorithm is also included in this package. While the traditional OLS approach assumes all independent variables have a linear relationship with the response variable, this tests for non linear relationships to see if this leads to an improvement in model performance. 

Full documentation is available in the package with the help command.
